@@ -19,6 +19,13 @@ describe 'gnocchi::storage' do
       it 'configures backend_url' do
         is_expected.to contain_gnocchi_config('storage/coordination_url').with_value('redis://localhost:6379')
       end
+
+      it 'installs python-redis package' do
+         is_expected.to contain_package(platform_params[:redis_package_name]).with(
+           :name => platform_params[:redis_package_name],
+           :tag  => 'openstack'
+         )
+      end
     end
   end
 
@@ -30,6 +37,15 @@ describe 'gnocchi::storage' do
         facts.merge!(OSDefaults.get_facts())
       end
 
+      let(:platform_params) do
+         case facts[:osfamily]
+         when 'Debian'
+           { :redis_package_name     => 'python-redis' }
+         when 'RedHat'
+           { :redis_package_name     => 'python-redis' }
+         end
+       end
+
       it_behaves_like 'gnocchi-storage'
     end
   end
